@@ -1,6 +1,5 @@
 package pkg
 
 type RpmdbMetadata struct {
-	SourceRpm string
-	Epoch     *int
+	Epoch *int `json:"epoch"`
 }
