@@ -7,7 +7,6 @@ import (
 	"regexp"
 	"testing"
 
-	"github.com/sergi/go-diff/diffmatchpatch"
 	"github.com/stretchr/testify/assert"
 
 	"github.com/anchore/go-testutils"
@@ -119,10 +118,10 @@ func createImagePresenter(t *testing.T) *Presenter {
 	return pres
 }
 
-func createDirPresenter(t *testing.T) *Presenter {
+func createDirPresenter(t *testing.T, path string) *Presenter {
 	matches, packages := createResults()
 
-	s, err := source.NewFromDirectory("/some/path")
+	s, err := source.NewFromDirectory(path)
 	if err != nil {
 		t.Fatal(err)
 	}
@@ -132,6 +131,116 @@ func createDirPresenter(t *testing.T) *Presenter {
 	return pres
 }
 
+func Test_locationPath(t *testing.T) {
+	tests := []struct {
+		name     string
+		path     string
+		scheme   source.Scheme
+		real     string
+		virtual  string
+		expected string
+	}{
+		{
+			name:     "dir:.",
+			scheme:   source.DirectoryScheme,
+			path:     ".",
+			real:     "/home/usr/file",
+			virtual:  "file",
+			expected: "file",
+		},
+		{
+			name:     "dir:./",
+			scheme:   source.DirectoryScheme,
+			path:     "./",
+			real:     "/home/usr/file",
+			virtual:  "file",
+			expected: "file",
+		},
+		{
+			name:     "dir:./someplace",
+			scheme:   source.DirectoryScheme,
+			path:     "./someplace",
+			real:     "/home/usr/file",
+			virtual:  "file",
+			expected: "someplace/file",
+		},
+		{
+			name:     "dir:/someplace",
+			scheme:   source.DirectoryScheme,
+			path:     "/someplace",
+			real:     "file",
+			expected: "/someplace/file",
+		},
+		{
+			name:     "dir:/someplace symlink",
+			scheme:   source.DirectoryScheme,
+			path:     "/someplace",
+			real:     "/someplace/usr/file",
+			virtual:  "file",
+			expected: "/someplace/file",
+		},
+		{
+			name:     "dir:/someplace absolute",
+			scheme:   source.DirectoryScheme,
+			path:     "/someplace",
+			real:     "/usr/file",
+			expected: "/usr/file",
+		},
+		{
+			name:     "file:/someplace/file",
+			scheme:   source.FileScheme,
+			path:     "/someplace/file",
+			real:     "/usr/file",
+			expected: "/usr/file",
+		},
+		{
+			name:     "file:/someplace/file relative",
+			scheme:   source.FileScheme,
+			path:     "/someplace/file",
+			real:     "file",
+			expected: "file",
+		},
+		{
+			name:     "image",
+			scheme:   source.ImageScheme,
+			path:     "alpine:latest",
+			real:     "/etc/file",
+			expected: "/etc/file",
+		},
+		{
+			name:     "image symlink",
+			scheme:   source.ImageScheme,
+			path:     "alpine:latest",
+			real:     "/etc/elsewhere/file",
+			virtual:  "/etc/file",
+			expected: "/etc/file",
+		},
+	}
+
+	for _, test := range tests {
+		t.Run(test.name, func(t *testing.T) {
+			pres := createDirPresenter(t, test.path)
+			pres.srcMetadata = &source.Metadata{
+				Scheme: test.scheme,
+				Path:   test.path,
+			}
+
+			path := pres.packagePath(pkg.Package{
+				Locations: []source.Location{
+					{
+						Coordinates: source.Coordinates{
+							RealPath: test.real,
+						},
+						VirtualPath: test.virtual,
+					},
+				},
+			})
+
+			assert.Equal(t, test.expected, path)
+		})
+	}
+}
+
 func Test_imageToSarifReport(t *testing.T) {
 	pres := createImagePresenter(t)
 	s, err := pres.toSarifReport()
@@ -161,7 +270,7 @@ func Test_imageToSarifReport(t *testing.T) {
 }
 
 func Test_dirToSarifReport(t *testing.T) {
-	pres := createDirPresenter(t)
+	pres := createDirPresenter(t, "/abs/path")
 	s, err := pres.toSarifReport()
 	assert.NoError(t, err)
 
@@ -179,13 +288,13 @@ func Test_dirToSarifReport(t *testing.T) {
 	assert.Equal(t, "CVE-1999-0001-package-1", *result.RuleID)
 	assert.Len(t, result.Locations, 1)
 	location := result.Locations[0]
-	assert.Equal(t, "/some/path/etc/pkg-1", *location.PhysicalLocation.ArtifactLocation.URI)
+	assert.Equal(t, "/abs/path/etc/pkg-1", *location.PhysicalLocation.ArtifactLocation.URI)
 
 	result = run.Results[1]
 	assert.Equal(t, "CVE-1999-0002-package-2", *result.RuleID)
 	assert.Len(t, result.Locations, 1)
 	location = result.Locations[0]
-	assert.Equal(t, "/some/path/pkg-2", *location.PhysicalLocation.ArtifactLocation.URI)
+	assert.Equal(t, "/abs/path/pkg-2", *location.PhysicalLocation.ArtifactLocation.URI)
 }
 
 func TestSarifPresenterImage(t *testing.T) {
@@ -210,16 +319,12 @@ func TestSarifPresenterImage(t *testing.T) {
 	actual = redact(actual)
 	expected = redact(expected)
 
-	if !bytes.Equal(expected, actual) {
-		dmp := diffmatchpatch.New()
-		diffs := dmp.DiffMain(string(expected), string(actual), true)
-		t.Errorf("mismatched output:\n%s", dmp.DiffPrettyText(diffs))
-	}
+	assert.JSONEq(t, string(expected), string(actual))
 }
 
 func TestSarifPresenterDir(t *testing.T) {
 	var buffer bytes.Buffer
-	pres := createDirPresenter(t)
+	pres := createDirPresenter(t, ".")
 
 	// run presenter
 	err := pres.Present(&buffer)
@@ -238,11 +343,7 @@ func TestSarifPresenterDir(t *testing.T) {
 	actual = redact(actual)
 	expected = redact(expected)
 
-	if !bytes.Equal(expected, actual) {
-		dmp := diffmatchpatch.New()
-		diffs := dmp.DiffMain(string(expected), string(actual), true)
-		t.Errorf("mismatched output:\n%s", dmp.DiffPrettyText(diffs))
-	}
+	assert.JSONEq(t, string(expected), string(actual))
 }
 
 func redact(s []byte) []byte {
