@@ -1,7 +1,7 @@
 package vulnerability
 
 import (
-	grypeDb "github.com/anchore/grype-db/pkg/db/v3"
+	grypeDb "github.com/anchore/grype/grype/db/v3"
 )
 
 type Fix struct {
