@@ -1,5 +1,5 @@
 package vulnerability
 
-import grypeDB "github.com/anchore/grype-db/pkg/db/v3"
+import grypeDB "github.com/anchore/grype/grype/db/v3"
 
 const SchemaVersion = grypeDB.SchemaVersion
