@@ -2,18 +2,19 @@ package integration
 
 import (
 	"fmt"
-	"github.com/anchore/syft/syft/format"
 	"os"
 	"testing"
 
+	"github.com/scylladb/go-set/strset"
+	"github.com/stretchr/testify/assert"
+
 	"github.com/anchore/grype/grype"
 	"github.com/anchore/grype/grype/db"
 	"github.com/anchore/grype/internal"
+	"github.com/anchore/syft/syft"
 	syftPkg "github.com/anchore/syft/syft/pkg"
+	"github.com/anchore/syft/syft/sbom"
 	"github.com/anchore/syft/syft/source"
-	"github.com/stretchr/testify/assert"
-
-	"github.com/scylladb/go-set/strset"
 )
 
 var imagesWithVulnerabilities = []string{
@@ -27,10 +28,10 @@ var imagesWithVulnerabilities = []string{
 }
 
 func TestCompareSBOMInputToLibResults(t *testing.T) {
-	formats := []format.Option{
-		format.JSONOption,
-		format.SPDXJSONOption,
-		format.SPDXTagValueOption,
+	formats := []sbom.FormatID{
+		syft.JSONFormatID,
+		syft.SPDXJSONFormatID,
+		syft.SPDXTagValueFormatID,
 	}
 
 	// get a grype DB
@@ -58,8 +59,12 @@ func TestCompareSBOMInputToLibResults(t *testing.T) {
 		imageArchive := PullThroughImageCache(t, image)
 		imageSource := fmt.Sprintf("docker-archive:%s", imageArchive)
 
-		for _, f := range formats {
-			t.Run(fmt.Sprintf("%s/%s", image, f), func(t *testing.T) {
+		for _, formatID := range formats {
+			f := syft.FormatByID(formatID)
+			if f == nil {
+				t.Errorf("Invalid formatID: %s", formatID)
+			}
+			t.Run(fmt.Sprintf("%s/%s", image, formatID), func(t *testing.T) {
 
 				// get SBOM from syft, write to temp file
 				sbomBytes := getSyftSBOM(t, imageSource, f)
